@@ -550,8 +550,7 @@ class InstitutionalPortfolio:
 
         try:
             if method == 'ledoit_wolf':
-                lw = LedoitWolf()
-                clw = LedoitWolf().fit(valid_data)
+                lw = LedoitWolf().fit(valid_data)
                 cov_matrix = lw.covariance_
 
             elif method == 'sample':
@@ -1109,23 +1108,36 @@ class InstitutionalPortfolio:
             self.logger.warning("Insufficient data for risk model initialization")
 
     def _detect_and_handle_conflicts(self, df_day):
-        """Enhanced conflict detection with resolution strategies"""
-        return None
-        # Group by ticker and detect conflicts
-        # ticker_groups = df_day.groupby('ticker')
-        #
-        # df_day['direction_flag'] = 0
-        #
-        # for ticker, group in ticker_groups:
-        #     if len(signals.unique()) > 1 and 0 not in signals.unique():
-        #         # Mark conflicting entries
-        #         df_day.loc[df_day['ticker'] == ticker, 'direction_flag'] = 42
-        #
-        #         # Resolution strategy: keep strongest signal
-        #         strongest_signal_idx = group['signal_descriptor'].abs().idxmax()
-        #         df_day.loc[(df_day['ticker'] == ticker) & (df_day.index != strongest_signal_idx), 'signal'] = 0
-        #
-        # return df_day
+        """
+        Enhanced conflict detection using `signal_descriptor` column.
+        If a ticker has conflicting signals (both positive and negative),
+        resolve by keeping only the strongest signal.
+        """
+
+        # Add a helper flag column
+        df_day['direction_flag'] = 0
+
+        # Group by ticker and check signals
+        ticker_groups = df_day.groupby('ticker')
+
+        for ticker, group in ticker_groups:
+            signals = group['signal_descriptor'].dropna()
+
+            if len(signals) > 1:
+                # Detect both positive and negative signals (conflict)
+                has_pos = (signals > 0).any()
+                has_neg = (signals < 0).any()
+
+                if has_pos and has_neg:
+                    # Mark conflicting entries
+                    df_day.loc[df_day['ticker'] == ticker, 'direction_flag'] = 42
+
+                    # Resolution: keep the strongest absolute signal
+                    strongest_idx = group['signal_descriptor'].abs().idxmax()
+                    df_day.loc[(df_day['ticker'] == ticker) & (df_day.index != strongest_idx),
+                    'signal_descriptor'] = 0.0
+
+        return df_day
 
     def _should_rebalance(self, current_date):
         """Enhanced rebalancing logic with market conditions"""
